const setupContent = require("../setup/index");
const graphContent = require("../guides/index");
const notionContent = require('../notion/index')
module.exports = {
    title: "博锐尚格 Web 组件开发文档",
    description: "博锐尚格 Web 组件开发文档",
    base: "/web/",
    plugins: [
        "@vuepress/last-updated",
        "plugin-back-to-top",
        [
            'vuepress-plugin-typescript',
            {
                tsLoaderOptions: {},
            },
        ],
        [
            'vuepress-plugin-mathjax',
            {
                target: 'svg',
                macros: {
                    '*': '\\times',
                },
            },
        ],
    ],
    markdown: {
        lineNumbers: true
    },
    themeConfig: {
        logo: "/assets/img/logo.png",
        nav: [{
                text: "首页",
                link: "/"
            },
            {
                text: "安装配置",
                items: [{
                        text: "开发环境",
                        items: [{
                                text: "IDEA",
                                link: "/setup/ide/idea"
                            },
                            {
                                text: "VS Code",
                                link: "/setup/ide/vscode"
                            },
                            {
                                text: "Node.js",
                                link: "/setup/ide/nodejs"
                            },
                            {
                                text: "vue-cli",
                                link: "/setup/ide/vuecli"
                            },
                            {
                                text: "plantUML",
                                link: "/setup/ide/plantUML"
                            }
                        ]
                    },
                    {
                        text: "服务器",
                        items: [{
                               text: "基础配置",
                                    link: "/setup/server/nginx"
                               },{
                                text: "应用配置",
                                link: "/setup/application/tuopu"
                             }
                        ]
                    },
                ]
            },
            {
                text: "开发文档",
                items: [
                    {
                        text: "引擎",
                        items: [
                            {text: "数据格式", link: "/guides/format/floorMap.md"},
                            {text: "图形引擎", link: "/guides/engine/"},
                            {text: "场景管理", link: "/guides/scene/"},
                            {text: "楼层平面图", link: "/guides/big/"},
                            // {text: "系统图", link: "/guides/system-diagram/"},
                            {text: "编辑器", link: "/guides/edit/"}
                        ]
                    },
                ]
            },
            {
                text:"开发规范",
                items: [
                    // {text: "javascript", link: "/guides/standard/javascript.md"},
                    // {text: "typescript", link: "/guides/standard/typescript.md"},
                    {text: "约定", link: "/guides/standard/appoint.md"},
                    {text: "git", link: "/guides/standard/git.md"}
                ]
            },
            {
                text: "API参考",
                items: [{
                    text: "图形引擎",
                    link: "http://doc.sagacloud.cn/api/web/graph/"
                },
                    {
                        text: "建筑信息图",
                        link: "http://doc.sagacloud.cn/api/web/big/"
                    },
                    {
                        text: "编辑器",
                        link: "http://doc.sagacloud.cn/api/web/edit/"
                    }
                ]
            },
            // {
            //     text: "概念解释",
            //     items: [{
            //         text: "系统图相关",
            //         items: [{
            //             text: "系统图",
            //             link: "/notion/system/system.md"
            //         },]
            //     }, {
            //         text: "服务相关",
            //         items: [{
            //             text: "数据中台",
            //             link: "/notion/middle/middle.md"
            //         }, {
            //             text: "数据中心",
            //             link: "/notion/center/center.md"
            //         }, {
            //             text: "蜡笔森林",
            //             link: "/notion/crayon/crayon.md"
            //         }]
            //     }, {
            //         text: "Revit",
            //         items: [{
            //             text: "Revit",
            //             link: "/notion/revit/revit.md"
            //         }]
            //     }]
            // }
        ],
        displayAllHeaders: true,
        sidebarDepth: 0,
        sidebar: {
            "/setup/": setupContent,
            "/guides/": graphContent,
            "/notion": notionContent
        }
    },
    module: {
        rules: [{
            test: /\.less$/,
            loader: 'less-loader', // compiles Less to CSS
        }, ],
    },
    devServer :{
        proxy: {
            '/gogs': {
                target: 'http://39.106.8.246:3003',
                changeOrigin: true,
                secure: false,
                pathRewrite: {
                    '^/gogs': '',
                },
                bypass: function(req, res, proxyOptions) {
                    req.headers["Authorization"] = "Basic bGJzbDoyMDIwMDgyOQ=="
                }
            }
        }
    },

};
